# testmynb
Test My Notebook, or testmynb, is a framework which allows users to write and run Jupyter Notebook code cells as tests.


## Install
```sh
pip install testmynb
```


## Usage
```sh
testmynb
```
